@@ -6,7 +6,6 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
 
   # Read and preprocess test data
   parse_test_examples <- function(input) {
-
     third_dim_names <- c(
       "ABSENT", "LEVEL", "ALTITUDE", "ELEVATION", "", "", "CUSTOM1", "CUSTOM2"
     )
@@ -48,27 +47,26 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
         third_dim = header[3],
         coords = coords
       )
-
     })
   }
 
   # Original lines
   org <- parse_test_examples(
     readLines(
-      system.file("test/original.txt", package="flexpolyline")
+      system.file("test/original.txt", package = "flexpolyline")
     )
   )
 
   # Decoded lines
   dec <- parse_test_examples(
     readLines(
-      system.file("test/round_half_even/decoded.txt", package="flexpolyline")
+      system.file("test/round_half_even/decoded.txt", package = "flexpolyline")
     )
   )
 
   # Encoded lines
   enc <- readLines(
-    system.file("test/round_half_even/encoded.txt", package="flexpolyline")
+    system.file("test/round_half_even/encoded.txt", package = "flexpolyline")
   )
 
   # Test encoding
@@ -79,13 +77,13 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
         # Omit reserved dimensions and encoding with precision higher than 7
         if (
           is.na(org[[i]]$third_dim_precision) |
-          is.na(org[[i]]$precision)
-        ) return(FALSE)
-        if (
-          org[[i]]$third_dim %in% c(4, 5) |
-          org[[i]]$third_dim_precision > 7 |
-          org[[i]]$precision > 7
-        ) return(FALSE)
+            is.na(org[[i]]$precision)
+        ) {
+          return(FALSE)
+        }
+        if (org[[i]]$third_dim %in% c(4, 5)) {
+          return(FALSE)
+        }
 
         # Encode
         encoded <- encode(
@@ -97,7 +95,6 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
 
         # Test equality
         enc[i] != encoded
-
       }, logical(1))
     ),
     FALSE
@@ -111,13 +108,13 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
         # Omit reserved dimensions and decoding with precision higher than 7
         if (
           is.na(dec[[i]]$third_dim_precision) |
-          is.na(dec[[i]]$precision)
-        ) return(FALSE)
-        if (
-          dec[[i]]$third_dim %in% c(4, 5) |
-          dec[[i]]$third_dim_precision > 7 |
-          dec[[i]]$precision > 7
-        ) return(FALSE)
+            is.na(dec[[i]]$precision)
+        ) {
+          return(FALSE)
+        }
+        if (dec[[i]]$third_dim %in% c(4, 5)) {
+          return(FALSE)
+        }
 
         # Encode
         decoded <- decode(
@@ -126,7 +123,6 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
 
         # Test equality
         any(dec[[i]]$coords != decoded)
-
       }, logical(1))
     ),
     FALSE
@@ -134,11 +130,10 @@ test_that("Cpp binding to 'flexpolyline.h' en- and decodes correctly", {
 
   # Input checks
   skip_on_cran()
-  expect_error(encode(matrix(1,2,4)), "Invalid input dimensions", class = "std::invalid_argument")
-  expect_error(encode(matrix(1,2,3), precision = -1), "precision out of range", class = "std::out_of_range")
-  expect_error(encode(matrix(1,2,3), third_dim = -1), "third_dim out of range", class = "std::out_of_range")
-  expect_error(encode(matrix(1,2,3), third_dim_precision = -1), "third_dim_precision out of range", class = "std::out_of_range")
+  expect_error(encode(matrix(1, 2, 4)), "Invalid input dimensions", class = "std::invalid_argument")
+  expect_error(encode(matrix(1, 2, 3), precision = -1), "precision out of range", class = "std::out_of_range")
+  expect_error(encode(matrix(1, 2, 3), third_dim = -1), "third_dim out of range", class = "std::out_of_range")
+  expect_error(encode(matrix(1, 2, 3), third_dim_precision = -1), "third_dim_precision out of range", class = "std::out_of_range")
   expect_error(decode("123"), "Invalid encoding", class = "std::invalid_argument")
   expect_error(set_third_dimension("BlBoz5xJ67i1BU1B7PUzIhaUxL7YU", "NOT A DIM"), "Invalid input name of third dimension", class = "std::invalid_argument")
-
 })
